( cd usr/lib ; rm -rf libipoddevice.so.0 )
( cd usr/lib ; ln -sf libipoddevice.so.0.0.0 libipoddevice.so.0 )
( cd usr/lib ; rm -rf libipoddevice.so )
( cd usr/lib ; ln -sf libipoddevice.so.0.0.0 libipoddevice.so )
